<?php
/**
 * components functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Theme Palace
 */


if ( ! function_exists( 'create_magazine_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the aftercomponentsetup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function create_magazine_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on components, use a find and replace
	 * to change 'create-magazine' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'create-magazine', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 600, 300, true );

	// custom image size
	add_image_size( 'create-magazine-featured-category', 390, 506, true );

	add_image_size( 'create-magazine-recent-storys', 450, 338, true );
	
	add_image_size( 'create-magazine-photo-gallery', 500, 666, true );

	add_image_size( 'create-magazine-featured-trending', 275, 206, true );

	// top categories
	add_image_size( 'create-magazine-top-categories-large', 424, 318, true );
	add_image_size( 'create-magazine-top-categories-medium', 318, 318, true );
	
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary'   => esc_html__( 'Primary', 'create-magazine' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'create_magazine_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'assets/css/editor-style.min.css' ) );

	
	add_theme_support( 'custom-logo', array(
		'flex-height' => true,
		'flex-width'  => true,
		'header-text' => array( 'site-title', 'site-description' ),
	) );

	// Gutenberg support
		add_theme_support( 'editor-color-palette', array(
	       	array(
				'name' => esc_html__( 'Blue', 'create-magazine' ),
				'slug' => 'blue',
				'color' => '#27A5E0',
	       	),
	       	array(
	           	'name' => esc_html__( 'Green', 'create-magazine' ),
	           	'slug' => 'green',
	           	'color' => '#5FAC5A',
	       	),
	       	array(
	           	'name' => esc_html__( 'Black', 'create-magazine' ),
	           	'slug' => 'black',
	           	'color' => '#000',
	       	),
	       	array(
	           	'name' => esc_html__( 'Grey', 'create-magazine' ),
	           	'slug' => 'grey',
	           	'color' => '#82868b',
	       	),
	   	));

		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-font-sizes', array(
		   	array(
		       	'name' => esc_html__( 'small', 'create-magazine' ),
		       	'shortName' => esc_html__( 'S', 'create-magazine' ),
		       	'size' => 12,
		       	'slug' => 'small'
		   	),
		   	array(
		       	'name' => esc_html__( 'regular', 'create-magazine' ),
		       	'shortName' => esc_html__( 'M', 'create-magazine' ),
		       	'size' => 16,
		       	'slug' => 'regular'
		   	),
		   	array(
		       	'name' => esc_html__( 'larger', 'create-magazine' ),
		       	'shortName' => esc_html__( 'L', 'create-magazine' ),
		       	'size' => 36,
		       	'slug' => 'larger'
		   	),
		   	array(
		       	'name' => esc_html__( 'huge', 'create-magazine' ),
		       	'shortName' => esc_html__( 'XL', 'create-magazine' ),
		       	'size' => 48,
		       	'slug' => 'huge'
		   	)
		));
		add_theme_support('editor-styles');
		add_theme_support( 'wp-block-styles' );
}
endif;
add_action( 'after_setup_theme', 'create_magazine_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function create_magazine_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'create_magazine_content_width', 640 );
}
add_action( 'after_setup_theme', 'create_magazine_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function create_magazine_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'create-magazine' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget-wrap %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Secondary Sidebar', 'create-magazine' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'This sidebar will be only visible on archive pages', 'create-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget-wrap %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'create_magazine_widgets_init' );

if ( ! function_exists( 'create_magazine_fonts_url' ) ) :
/**
 * Register Google fonts for Create Magazine
 *
 * Create your own create_magazine_fonts_url() function to override in a child theme.
 *
 * @since Create Magazine 2.0
 *
 * @return string Google fonts URL for the theme.
 */
function create_magazine_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	// translators: If there are characters in your language that are not supported by open sans, translate this to 'off'. Do not translate into your own language. 
	if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'create-magazine' ) ) {
		$fonts[] = 'Open Sans';
	}

	/* translators: If there are characters in your language that are not supported by Montserrat, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Montserrat font: on or off', 'create-magazine' ) ) {
		$fonts[] = 'Montserrat';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}
	return $fonts_url;
}
endif;

/**
 * Enqueue scripts and styles.
 */
function create_magazine_scripts() {

	$options = create_magazine_get_theme_options();
	$animated_layout = $options['site_animation_layout'];
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'create-magazine-fonts', create_magazine_fonts_url(), array(), null );

	// Add fontawesome
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/plugins/fontawesome/css/font-awesome.min.css', '', '4.6.3' );

	//Add animation style
	if ( $animated_layout == true ){
		wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.min.css', '', '3.5.1' );
	}

	//Add sidr light style
	wp_enqueue_style( 'sidr-light', get_template_directory_uri() . '/assets/css/jquery-sidr-light.min.css', '', false );

	//Add prettyPhoto style
	wp_enqueue_style( 'preetyPhoto', get_template_directory_uri() . '/assets/css/prettyPhoto.min.css', '', '3.1.6' );

	// Theme stylesheet.
	wp_enqueue_style( 'create-magazine-style', get_stylesheet_uri() );

	$theme_color = ! empty( $options['theme_color'] ) ? $options['theme_color'] : 'default';
	wp_enqueue_style( 'create-magazine-color', get_template_directory_uri() . '/assets/css/' . $theme_color . '.min.css', array(), '' );

	// blocks
	wp_enqueue_style( 'create-magazine-blocks', get_template_directory_uri() . '/assets/css/blocks.min.css' );

	// Add default style
	wp_enqueue_style( 'create-magazine-default', get_template_directory_uri() . '/assets/css/default.min.css', '', false );

	// Add navigation script
	wp_enqueue_script( 'create-magazine-navigation', get_template_directory_uri() . '/assets/js/navigation.min.js', array(), '20151215', true );

	// Add skip link focus script
	wp_enqueue_script( 'create-magazine-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.min.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Add cycle2 js
	wp_enqueue_script( 'cycle2', get_template_directory_uri() . '/assets/plugins/cycle2/cycle2.min.js', array( 'jquery' ), '2.1.6', true );

	// Add cycle2 carousel
	wp_enqueue_script( 'cycle2-carousel', get_template_directory_uri() . '/assets/plugins/cycle2/jquery.cycle2.carousel.min.js', array( 'jquery', 'cycle2' ), '20141007', true );

	// Add cycle2 Flip vertical
	wp_enqueue_script( 'cycle2-flip', get_template_directory_uri() . '/assets/plugins/cycle2/jquery.cycle2.flip.min.js', array( 'jquery', 'cycle2' ), '20141007', true );

	// Add animate js
	if ( $animated_layout == true ){
		wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/assets/js/waypoints.min.js', array( 'jquery' ), '', true );
	}
	// Add sidr js
	wp_enqueue_script( 'sidr', get_template_directory_uri() . '/assets/js/jquery.sidr.min.js', array( 'jquery' ), '', true );

	// Add smoothscroll js
	wp_enqueue_script( 'smoothscroll', get_template_directory_uri() . '/assets/js/jquery.smooth-scroll.min.js', array( 'jquery' ), '', true );

	// Add prettyphoto js
	wp_enqueue_script( 'prettyphoto', get_template_directory_uri() . '/assets/js/jquery.prettyPhoto.min.js', array( 'jquery' ), '', true );
	
	// Add custom js
	wp_enqueue_script( 'create-magazine-custom', get_template_directory_uri() . '/assets/js/custom.min.js', array( 'jquery' ), '', true );

	// Add animation js
	if ( $animated_layout == true ){
		wp_enqueue_script( 'create-magazine-animation', get_template_directory_uri() . '/assets/js/animation.min.js', array( 'jquery' ), '', true );
	}
}
add_action( 'wp_enqueue_scripts', 'create_magazine_scripts' );

/**
 * Enqueue editor styles for Gutenberg
 *
 * @since Create Magazine Pro 1.0.0
 */
function create_magazine_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'create-magazine-block-editor-style', get_theme_file_uri( '/assets/css/editor-blocks.min.css' ) );
	// Add custom fonts.
	wp_enqueue_style( 'create-magazine-fonts', create_magazine_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'create_magazine_block_editor_styles' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Create Magazine core file
 */
require get_template_directory() . '/inc/core.php';

/*
*Register gallery thumbnail size to media.
*/
function create_magazine_custom_sizes( $sizes ) {
    return array_merge( $sizes, array(
        'create-magazine-photo-gallery' => esc_html__( 'Galley Thumbnail', 'create-magazine' ),
    ) );
}
add_filter( 'image_size_names_choose', 'create_magazine_custom_sizes' );


/**
 * Load theme updater functions.
 * Action is used so that child themes can easily disable.
 */

function create_magazine_theme_updater() {
	if( is_admin() ) {
		require( get_template_directory() . '/updater/theme-updater.php' );
	}
}
add_action( 'after_setup_theme', 'create_magazine_theme_updater' );
