<?php
/**
 * Create Magazine customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

if ( ! function_exists( 'create_magazine_is_featured_category_active' ) ) :
	/**
	 * Check if featured category is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_featured_category_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$featured_category_enable = $control->manager->get_setting( 'create_magazine_theme_options[featured_category_enable]' )->value();

		if ( $featured_category_enable == 'entire-site'  || ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $featured_category_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_featured_category_demo_content_active' ) ) :
	/**
	 * Check if featured category content type demo is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_featured_category_demo_content_active( $control ) {
		if ( create_magazine_is_featured_category_active( $control ) && 'demo' != $control->manager->get_setting( 'create_magazine_theme_options[featured_category_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_featured_category_page_content_active' ) ) :
	/**
	 * Check if featured category content type page is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_featured_category_page_content_active( $control ) {
		if ( create_magazine_is_featured_category_active( $control ) && 'page' == $control->manager->get_setting( 'create_magazine_theme_options[featured_category_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_featured_category_post_content_active' ) ) :
	/**
	 * Check if featured category content type post is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_featured_category_post_content_active( $control ) {
		if ( create_magazine_is_featured_category_active( $control ) && 'post' == $control->manager->get_setting( 'create_magazine_theme_options[featured_category_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_recent_story_active' ) ) :
	/**
	 * Check if recent story is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_recent_story_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$recent_story_enable = $control->manager->get_setting( 'create_magazine_theme_options[recent_story_enable]' )->value();

		if ( ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $recent_story_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_recent_story_category_content_active' ) ) :
	/**
	 * Check if recent story category content type post is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_recent_story_category_content_active( $control ) {
		if ( create_magazine_recent_story_active( $control ) && 'category' == $control->manager->get_setting( 'create_magazine_theme_options[recent_story_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_is_category_block_one_active' ) ) :
	/**
	 * Check if category block one is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_category_block_one_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$category_block_one_enable = $control->manager->get_setting( 'create_magazine_theme_options[category_block_one_enable]' )->value();

		if ( ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $category_block_one_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_category_block_one_demo_content_active' ) ) :
	/**
	 * Check if category block one content type demo is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_category_block_one_demo_content_active( $control ) {
		if ( create_magazine_is_category_block_one_active( $control ) && 'demo' != $control->manager->get_setting( 'create_magazine_theme_options[category_block_one_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_category_block_one_post_content_active' ) ) :
	/**
	 * Check if category block one content type post is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_category_block_one_post_content_active( $control ) {
		if ( create_magazine_is_category_block_one_active( $control ) && 'post' == $control->manager->get_setting( 'create_magazine_theme_options[category_block_one_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_category_block_one_category_content_active' ) ) :
	/**
	 * Check if category block one content type category is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_category_block_one_category_content_active( $control ) {
		if ( create_magazine_is_category_block_one_active( $control ) && 'category' == $control->manager->get_setting( 'create_magazine_theme_options[category_block_one_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_category_block_one_tag_content_active' ) ) :
	/**
	 * Check if category block one content type tag is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_category_block_one_tag_content_active( $control ) {
		if ( create_magazine_is_category_block_one_active( $control ) && 'tag' == $control->manager->get_setting( 'create_magazine_theme_options[category_block_one_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'create_magazine_theme_options[loader_enable]' )->value();
	}
endif;


if ( ! function_exists( 'create_magazine_is_loader_icon_type_enable' ) ) :
	/**
	 * Check if loader icon type is enabled.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_loader_icon_type_enable( $control ) {
		if ( ( create_magazine_is_loader_enable( $control )) && ( 'icon' ==  $control->manager->get_setting( 'create_magazine_theme_options[loader_type]' )->value() ) )
			return true;
		else
			return false;
	}
endif;


if ( ! function_exists( 'create_magazine_is_loader_image_type_enable' ) ) :
	/**
	 * Check if loader image type is enabled.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_loader_image_type_enable( $control ) {
		if ( ( create_magazine_is_loader_enable( $control ) ) && ( 'image' ==  $control->manager->get_setting( 'create_magazine_theme_options[loader_type]' )->value() ) )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'create_magazine_featured_story_active' ) ) :
	/**
	 * Check if featured story is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_featured_story_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$featured_story_enable = $control->manager->get_setting( 'create_magazine_theme_options[featured_story_enable]' )->value();

		if ( ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $featured_story_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_featured_story_content_category' ) ) :
	/**
	 * Check if featured story content type is category.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_featured_story_content_category( $control ) {
		if ( ('category' == $control->manager->get_setting( 'create_magazine_theme_options[featured_story_type]' )->value() ) && (create_magazine_featured_story_active( $control ) ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_featured_story_content_tag' ) ) :
	/**
	 * Check if featured story content type is tag.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_featured_story_content_tag( $control ) {
		if ( 'tag' == $control->manager->get_setting( 'create_magazine_theme_options[featured_story_type]' )->value() && (create_magazine_featured_story_active( $control ) ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_featured_story_content_post' ) ) :
	/**
	 * Check if featured story content type is  post.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_featured_story_content_post( $control ) {
		if ( 'post' == $control->manager->get_setting( 'create_magazine_theme_options[featured_story_type]' )->value() && create_magazine_featured_story_active( $control ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_featured_story_content_demo' ) ) :
	/**
	 * Check if featured story content type is demo.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_featured_story_content_demo( $control ) {
		if ( 'demo' != $control->manager->get_setting( 'create_magazine_theme_options[featured_story_type]' )->value() && create_magazine_featured_story_active( $control ) )
			return true;

		return false;
	}
endif;



if ( ! function_exists( 'create_magazine_is_primary_menu_enable' ) ) :
	/**
	 * Check if primary menu is enabled.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_primary_menu_enable( $control ) {
		if ( 0 ==  $control->manager->get_setting( 'create_magazine_theme_options[disable_primary_menu]' )->value() ) 
			return true;
		else
			return false;
	}
endif;


if ( ! function_exists( 'create_magazine_is_headline_active' ) ) :
	/**
	 * Check if headline is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_headline_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$headline_enable = $control->manager->get_setting( 'create_magazine_theme_options[headline_enable]' )->value();

		if ( $headline_enable == 'entire-site'  || ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $headline_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_headline_category_type_active' ) ) :
	/**
	 * Check if headline category type is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_headline_category_type_active( $control ) {
		if ((create_magazine_is_headline_active( $control )) && ('category' == $control->manager->get_setting( 'create_magazine_theme_options[headline_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_photo_gallery_active' ) ) :
	/**
	 * Check if photo gallery is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_photo_gallery_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$gallery_enable = $control->manager->get_setting( 'create_magazine_theme_options[gallery_enable]' )->value();

		if ( ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $gallery_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_photo_gallery_type' ) ) :
	/**
	 * Check if photo gallery content type is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_photo_gallery_type( $control ) {
		if (  create_magazine_photo_gallery_active( $control ) && 'custom' == $control->manager->get_setting( 'create_magazine_theme_options[gallery_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_trending_now_active' ) ) :
	/**
	 * Check if trending now is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_trending_now_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$trending_now_enable = $control->manager->get_setting( 'create_magazine_theme_options[trending_now_enable]' )->value();

		if ( ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $trending_now_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_trending_now_content_category' ) ) :
	/**
	 * Check if trending now content type is category.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_trending_now_content_category( $control ) {
		if ( ('category' == $control->manager->get_setting( 'create_magazine_theme_options[trending_now_type]' )->value() ) && (create_magazine_trending_now_active( $control ) ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_trending_now_content_tag' ) ) :
	/**
	 * Check if trending now content type is tag.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_trending_now_content_tag( $control ) {
		if ( 'tag' == $control->manager->get_setting( 'create_magazine_theme_options[trending_now_type]' )->value() && (create_magazine_trending_now_active( $control ) ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_trending_now_content_demo' ) ) :
	/**
	 * Check if trending now content type is post.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_trending_now_content_demo( $control ) {
		if ( 'demo' != $control->manager->get_setting( 'create_magazine_theme_options[trending_now_type]' )->value() && create_magazine_trending_now_active( $control ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_contact_details_active' ) ) :
	/**
	 * Check if contact details is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_contact_details_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'create_magazine_theme_options[contact_details_enable]' )->value() )
			return true;

		return false;
	}
endif;


// culture section
if ( ! function_exists( 'create_magazine_category_block_two_active' ) ) :
	/**
	 * Check if category block two is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_category_block_two_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$category_block_two_enable = $control->manager->get_setting( 'create_magazine_theme_options[category_block_two_enable]' )->value();

		if ( ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $category_block_two_enable == 'static-frontpage' ) 
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_category_block_two_content_category' ) ) :
	/**
	 * Check if category block two content type is category.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_category_block_two_content_category( $control ) {
		if ( ('category' == $control->manager->get_setting( 'create_magazine_theme_options[category_block_two_type]' )->value() ) && (create_magazine_category_block_two_active( $control ) ) )

			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_category_block_two_content_tag' ) ) :
	/**
	 * Check if category block two content type is tag.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */

	function create_magazine_category_block_two_content_tag( $control ) {
		if ( 'tag' == $control->manager->get_setting( 'create_magazine_theme_options[category_block_two_type]' )->value() && (create_magazine_category_block_two_active( $control ) ) )

			return true;

		return false;
	}

endif;

if ( ! function_exists( 'create_magazine_category_block_two_content_post' ) ) :
	/**
	 * Check if category block two content type  is post.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_category_block_two_content_post( $control ) {
		if ( 'post' == $control->manager->get_setting( 'create_magazine_theme_options[category_block_two_type]' )->value() && create_magazine_category_block_two_active( $control ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'create_magazine_category_block_two_content_demo' ) ) :
	/**
	 * Check if category block two content type is demo.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_category_block_two_content_demo( $control ) {
		if ( 'demo' != $control->manager->get_setting( 'create_magazine_theme_options[category_block_two_type]' )->value() && create_magazine_category_block_two_active( $control ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_top_categories_active' ) ) :
	/**
	 * Check if top categories active.
	 */
	function create_magazine_is_top_categories_active( $control ) {

		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$top_categories_enable = $control->manager->get_setting( 'create_magazine_theme_options[top_categories_enable]' )->value();

		if ( ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $top_categories_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_top_categories_category_active' ) ) :
	/**
	 * Check if top categories category is active.
	*/
	function create_magazine_is_top_categories_category_active( $control ) {
		if ( ('category' == $control->manager->get_setting( 'create_magazine_theme_options[top_categories_content_type]' )->value() ) && ( create_magazine_is_top_categories_active( $control ) ) )
			return true;

		return false;
	}
endif;

// category block three  section
if ( ! function_exists( 'create_magazine_is_category_block_three_active' ) ) :
	/**
	 * Check if category block three is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_category_block_three_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_on_front  = get_option('page_on_front') ;

		$category_block_three_enable = $control->manager->get_setting( 'create_magazine_theme_options[category_block_three_enable]' )->value();

		if ( ( ( $page_id == $page_on_front ) && $page_id > 0 ) && $category_block_three_enable == 'static-frontpage' )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'create_magazine_is_category_block_three_content_category_active' ) ) :
	/**
	 * Check if category block three category content is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_category_block_three_content_category_active( $control ) {
		if ( ( 'category' == $control->manager->get_setting( 'create_magazine_theme_options[category_block_three_content_type]' )->value() ) && (create_magazine_is_category_block_three_active( $control ) ) )
			return true;

		return false;
	}
endif;

// related posts options
if ( ! function_exists( 'create_magazine_is_related_posts_enable' ) ) :
	/**
	 * Check if related posts is active.
	 *
	 * @since 2.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function create_magazine_is_related_posts_enable( $control ) {

		$disable_related_posts = $control->manager->get_setting( 'create_magazine_theme_options[disable_related_posts]' )->value();

		if ( true == $disable_related_posts ) 
			return false;

		return true;
	}
endif;
