<?php
/**
 * Category Block Two Customizer options
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

// Add Category block two enable section
$wp_customize->add_section( 'create_magazine_category_block_two_section', array(
	'title'             => esc_html__( 'Category Block Two','create-magazine' ),
	'description'       => esc_html__( 'Category block two section options.', 'create-magazine' ),
	'priority'			=> '80',
	'panel'             => 'create_magazine_sections_panel'
) );

// Add Category block two enable setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_two_enable]', array(
	'default'           => $options['category_block_two_enable'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[category_block_two_enable]', array(
	'label'             => esc_html__( 'Enable on', 'create-magazine' ),
	'section'           => 'create_magazine_category_block_two_section',
	'type'              => 'select',
	'choices'           => create_magazine_enable_options()
) );

// Add Category block two title setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_two_title]', array(
	'default'           => $options['category_block_two_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'create_magazine_theme_options[category_block_two_title]', array(
	'label'             => esc_html__( 'Title', 'create-magazine' ),
	'section'           => 'create_magazine_category_block_two_section',
	'type'              => 'text',
	'active_callback'	=> 'create_magazine_category_block_two_content_demo'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'create_magazine_theme_options[category_block_two_title]', array(
		'selector'            => '#culture .widget-title h2',
		'render_callback'     => 'create_magazine_customize_partial_category_block_two_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add Category block two number setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[num_of_category_block_two]', array(
	'default'           => $options['num_of_category_block_two'],
	'sanitize_callback' => 'create_magazine_sanitize_number_range'
) );

$wp_customize->add_control( 'create_magazine_theme_options[num_of_category_block_two]', array(
	'label'             => esc_html__( 'No of Category block two', 'create-magazine' ),
	'description'		=> esc_html__( 'Max 8 Category block two. Save and referesh the page to add changing value.', 'create-magazine' ),
	'section'           => 'create_magazine_category_block_two_section',
	'input_attrs' 		=> array( 'min' => 1, 'max' => 4, 'style' => 'width: 100px;' ),
	'type'              => 'number',
	'active_callback'   => 'create_magazine_category_block_two_content_demo'
) );

// Add Category block two types setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_two_type]', array(
	'default'           => $options['category_block_two_type'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[category_block_two_type]', array(
	'label'             => esc_html__( 'Get Category block two From', 'create-magazine' ),
	'section'           => 'create_magazine_category_block_two_section',
	'type'              => 'select',
	'choices'			=> create_magazine_category_block_two_options(),
	'active_callback'	=> 'create_magazine_category_block_two_active'
) );

// Add Category block two category setting and control.
$wp_customize->add_setting(  'create_magazine_theme_options[category_block_two_content_category]', array(
	'default'           => $options['category_block_two_content_category'],
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Create_Magazine_Dropdown_Category_Control ( $wp_customize,'create_magazine_theme_options[category_block_two_content_category]', array(
	'label'             => esc_html__( 'Dropdown Category Control', 'create-magazine' ),
	'section'           => 'create_magazine_category_block_two_section',
	'type'              => 'dropdown-category',
	'active_callback'	=> 'create_magazine_category_block_two_content_category'
) ) );


// Add Category block two tag setting and control.
$wp_customize->add_setting(  'create_magazine_theme_options[category_block_two_content_tag]', array(
	'default'           => $options['category_block_two_content_tag'],
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Create_Magazine_Dropdown_Tag_Control ( $wp_customize,'create_magazine_theme_options[category_block_two_content_tag]', array(
	'label'             => esc_html__( 'Dropdown Tag Control', 'create-magazine' ),
	'section'           => 'create_magazine_category_block_two_section',
	'type'              => 'dropdown-tag',
	'active_callback'	=> 'create_magazine_category_block_two_content_tag'
) ) );

$value = create_magazine_get_theme_options();
$no_of_post = $value['num_of_category_block_two'];

for ( $i = 1; $i <= $no_of_post; $i++ ) {

	// insert category block two post id
	$wp_customize->add_setting( 'create_magazine_theme_options[category_block_two_post_id_' . $i . ']', array(
		'sanitize_callback' => 'create_magazine_sanitize_number_range'
	) );

	$wp_customize->add_control( 'create_magazine_theme_options[category_block_two_post_id_' . $i . ']', array(
		'label'             => esc_html__( 'Post id # ' , 'create-magazine' ) . $i,
		'section'           => 'create_magazine_category_block_two_section',
		'input_attrs' 		=> array( 
			'style' 		=> 'width: 100px;',
			'min'			=> '1', 
			'placeholder'	=> esc_attr__( 'Post ID', 'create-magazine' ) ),
		'type'              => 'number',
		'active_callback'	=> 'create_magazine_category_block_two_content_post'
	) );
}
