<?php
/**
 * Feature story Customizer options
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

// Add featured story enable section
$wp_customize->add_section( 'create_magazine_featured_story_section', array(
	'title'             => esc_html__( 'Featured Story','create-magazine' ),
	'description'       => esc_html__( 'Featured Story section options.', 'create-magazine' ),
	'priority'			=> '40',
	'panel'             => 'create_magazine_sections_panel'
) );

// Add featured story enable setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[featured_story_enable]', array(
	'default'           => $options['featured_story_enable'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[featured_story_enable]', array(
	'label'             => esc_html__( 'Enable on', 'create-magazine' ),
	'section'           => 'create_magazine_featured_story_section',
	'type'              => 'select',
	'choices'           => create_magazine_enable_options()
) );

// Add featured story title setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[featured_story_title]', array(
	'default'           => $options['featured_story_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'create_magazine_theme_options[featured_story_title]', array(
	'label'             => esc_html__( 'Title', 'create-magazine' ),
	'section'           => 'create_magazine_featured_story_section',
	'type'              => 'text',
	'active_callback'	=> 'create_magazine_featured_story_content_demo'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'create_magazine_theme_options[featured_story_title]', array(
		'selector'            => '#featured-story .bg-green h2.entry-title',
		'render_callback'     => 'create_magazine_customize_partial_featured_story_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add featured story number setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[num_of_featured_story]', array(
	'default'           => $options['num_of_featured_story'],
	'sanitize_callback' => 'create_magazine_sanitize_number_range'
) );

$wp_customize->add_control( 'create_magazine_theme_options[num_of_featured_story]', array(
	'label'             => esc_html__( 'No of Featured Story', 'create-magazine' ),
	'description'		=> esc_html__( 'Max 8 featured story. Save and referesh the page to add photo after changing value.', 'create-magazine' ),
	'section'           => 'create_magazine_featured_story_section',
	'input_attrs' 		=> array( 'min' => 1, 'max' => 8, 'style' => 'width: 100px;' ),
	'type'              => 'number',
	'active_callback'   => 'create_magazine_featured_story_content_demo'
) );

// Add featured story types setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[featured_story_type]', array(
	'default'           => $options['featured_story_type'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[featured_story_type]', array(
	'label'             => esc_html__( 'Get Featured Story From', 'create-magazine' ),
	'section'           => 'create_magazine_featured_story_section',
	'type'              => 'select',
	'choices'			=> create_magazine_featured_story_options(),
	'active_callback'	=> 'create_magazine_featured_story_active'
) );

// Add featured story category setting and control.
$wp_customize->add_setting(  'create_magazine_theme_options[featured_story_content_category]', array(
	'default'           => $options['featured_story_content_category'],
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Create_Magazine_Dropdown_Category_Control ( $wp_customize,'create_magazine_theme_options[featured_story_content_category]', array(
	'label'             => esc_html__( 'Dropdown Category Control', 'create-magazine' ),
	'section'           => 'create_magazine_featured_story_section',
	'type'              => 'dropdown-category',
	'active_callback'	=> 'create_magazine_featured_story_content_category'
) ) );


// Add featured story tag setting and control.
$wp_customize->add_setting(  'create_magazine_theme_options[featured_story_content_tag]', array(
	'default'           => $options['featured_story_content_tag'],
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Create_Magazine_Dropdown_Tag_Control ( $wp_customize,'create_magazine_theme_options[featured_story_content_tag]', array(
	'label'             => esc_html__( 'Dropdown Tag Control', 'create-magazine' ),
	'section'           => 'create_magazine_featured_story_section',
	'type'              => 'dropdown-tag',
	'active_callback'	=> 'create_magazine_featured_story_content_tag'
) ) );

$value = create_magazine_get_theme_options();
$no_of_post = $value['num_of_featured_story'];

for ( $i = 1; $i <= $no_of_post; $i++ ) {
	// insert featured story post id
	$wp_customize->add_setting( 'create_magazine_theme_options[post_id_' . $i . ']', array(
		'sanitize_callback' => 'create_magazine_sanitize_number_range'
	) );

	$wp_customize->add_control( 'create_magazine_theme_options[post_id_' . $i . ']', array(
		'label'             => esc_html__( 'Post id # ' , 'create-magazine' ) . $i,
		'section'           => 'create_magazine_featured_story_section',
		'input_attrs' 		=> array( 
			'style' 		=> 'width: 100px;',
			'min'			=> '1', 
			'placeholder'	=> esc_attr__( 'Post ID', 'create-magazine' ) ),
		'type'              => 'number',
		'active_callback'	=> 'create_magazine_featured_story_content_post'
	) );
}
