<?php
/**
 * Top Categories Customizer options
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */


// Add Top Categories section
$wp_customize->add_section( 'create_magazine_top_categories_section', array(
	'title'       		=> esc_html__( 'Top categories','create-magazine' ),
	'description' 		=> esc_html__( 'Top categories section options.', 'create-magazine' ),
	'priority'			=> '70',
	'panel'       		=> 'create_magazine_sections_panel'
) );

// Add Top Categories enable setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[top_categories_enable]', array(
	'default'         	=> $options['top_categories_enable'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[top_categories_enable]', array(
	'label'             => esc_html__( 'Enable on', 'create-magazine' ),
	'section'           => 'create_magazine_top_categories_section',
	'priority'			=> '10',
	'type'              => 'select',
	'choices'           => create_magazine_enable_options()
) );

// Add Top Categories content type setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[top_categories_content_type]', array(
	'default'           => $options['top_categories_content_type'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[top_categories_content_type]', array(
	'label'           => esc_html__( 'Content Type', 'create-magazine' ),
	'section'         => 'create_magazine_top_categories_section',
	'priority'		  => '20',
	'type'            => 'select',
	'active_callback' => 'create_magazine_is_top_categories_active',
	'choices'         => array(
		'demo'		  => esc_html__( 'Demo', 'create-magazine' ),
		'category'	  => esc_html__( 'Category', 'create-magazine' ),
	)
) );

// Add Top Categories section and control to title
$wp_customize->add_setting( 'create_magazine_theme_options[top_categories_title]', array(
	'default'           => $options['top_categories_title'],
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'create_magazine_theme_options[top_categories_title]', array(
	'label'           => esc_html__( 'Title', 'create-magazine' ),
	'section'         => 'create_magazine_top_categories_section',
	'priority'		  => '30',
	'active_callback' => 'create_magazine_is_top_categories_category_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'create_magazine_theme_options[top_categories_title]', array(
		'selector'            => '#top-categories h2.entry-title',
		'render_callback'     => 'create_magazine_customize_partial_top_categories_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add Top Categories section and control to show no of posts
$wp_customize->add_setting( 'create_magazine_theme_options[top_categories_no_of_posts]', array(
	'default'           => $options['top_categories_no_of_posts'],
	'sanitize_callback' => 'create_magazine_sanitize_number_range'
) );

$wp_customize->add_control( 'create_magazine_theme_options[top_categories_no_of_posts]', array(
	'label'           => esc_html__( 'No of Category', 'create-magazine' ),
	'section'         => 'create_magazine_top_categories_section',
	'priority'		  => '40',
	'active_callback' => 'create_magazine_is_top_categories_category_active',
	'type'			  => 'number',
	'input_attrs'	  => array(
		'min'		  => 1,
		'max'		  => 3,
		'style'		  => 'width:80px'
	)
) );

$no_of_post = $options['top_categories_no_of_posts'];

for( $i = 1; $i<= $no_of_post; $i++ ){
	// Add Top Categories setting and control to  select category
	$wp_customize->add_setting( 'create_magazine_theme_options[top_categories_content_category_'. $i .']', array(
	'default'           => $options['top_categories_content_category'],
	'sanitize_callback' => 'absint'
	) );

	$wp_customize->add_control( new Create_Magazine_Dropdown_Category_Control( $wp_customize, 'create_magazine_theme_options[top_categories_content_category_'. $i .']', array(
		'label'           => esc_html__( 'Category #', 'create-magazine' ). $i,
		'section'         => 'create_magazine_top_categories_section',
		'priority'		  => '5'. $i,
		'active_callback' => 'create_magazine_is_top_categories_category_active',
		'type'				=> 'dropdown-category',
		'input_attrs'		=> array(
			'style'        	=> 'width: 80px;'
		)
	) ) );

	// Add Top Categories setting and control to  add category image
	$wp_customize->add_setting( 'create_magazine_theme_options[top_categories_image_'. $i .']',
	  array(
	    'sanitize_callback' 	=> 'create_magazine_sanitize_image',
	) );
	$wp_customize->add_control(
	  new WP_Customize_Image_Control( $wp_customize, 'create_magazine_theme_options[top_categories_image_'. $i .']',
	    array(
	    	'label'      		=> esc_html__( 'Upload a Category image #', 'create-magazine' ) . $i,
	        'section'    		=> 'create_magazine_top_categories_section',
	        'priority'		  => '5'. $i .'.'. $i,
			'active_callback'	=> 'create_magazine_is_top_categories_category_active',
	) ) );
}
