<?php
/**
 * Adds a meta box to the post editing screen
 */
function create_magazine_custom_meta() {
	$post_types = array( 'post', 'page' );
    add_meta_box( 'create_magazine_meta', esc_html__( 'Theme Options', 'create-magazine' ), 'create_magazine_sidebar_position_callback', $post_types, 'side' );
}
add_action( 'add_meta_boxes', 'create_magazine_custom_meta' );


/**
 * Outputs the content of the sidebar position
 */
function create_magazine_sidebar_position_callback( $post ) {
	wp_nonce_field( basename( __FILE__ ), 'create_magazine_nonce' );
	$stored_sidebar_position = get_post_meta( $post->ID, 'create-magazine-sidebar-position', true );

	$sidebar_positions       = create_magazine_sidebar_position();
	 ?>

	<p>
     <label for="create-magazine-sidebar-position" class="create-magazine-row-title"><?php esc_html_e( 'Sidebar Position', 'create-magazine' )?></label>
     <select name="create-magazine-sidebar-position" id="create-magazine-sidebar-position">
      <option value=""><?php esc_html_e( 'Default ( to customizer option )', 'create-magazine' ); ?></option>

     	<?php foreach ( $sidebar_positions as $sidebar_position => $value ) { ?>
         <option value="<?php echo $sidebar_position;?>" <?php if ( isset ( $stored_sidebar_position ) ) selected( $stored_sidebar_position, $sidebar_position ); ?>><?php echo esc_html( $value ); ?></option>
     	<?php } ?>
     </select>
	</p>
	<?php
}


/**
 * Saves the sidebar position input
 */
function create_magazine_meta_save( $post_id ) {

    // Checks save status
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'create_magazine_nonce' ] ) && wp_verify_nonce( sanitize_key( $_POST[ 'create_magazine_nonce' ] ), basename( __FILE__ ) ) ) ? 'true' : 'false';

    // Exits script depending on save status
    if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
        return;
    }

    // Checks for input and sanitizes/saves if needed
    if( isset( $_POST[ 'create-magazine-sidebar-position' ] ) ) {
        update_post_meta( $post_id, 'create-magazine-sidebar-position', sanitize_text_field( $_POST[ 'create-magazine-sidebar-position' ] ) );
    }

}
add_action( 'save_post', 'create_magazine_meta_save' );