<?php
/**
 * Create Magazine options
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

/**
 * Enable options for static frontpage only
 * @return array Enable options
 */
function create_magazine_enable_options() {
	$create_magazine_enable_options = array(
		'static-frontpage' => esc_html__( 'Static Frontpage', 'create-magazine' ),
		'disabled'         => esc_html__( 'Disabled', 'create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_enable_options', $create_magazine_enable_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * Enable options for entire site ,static frontpage
 * @return array Enable options
 */
function create_magazine_enable_on_entire_site_options() {
	$create_magazine_enable_on_entire_site_options = array(
		'static-frontpage' => esc_html__( 'Static Frontpage', 'create-magazine' ),
		'entire-site'	   => esc_html__( 'Entire-Site', 'create-magazine' ),
		'disabled'         => esc_html__( 'Disabled', 'create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_enable_on_entire_site_options', $create_magazine_enable_on_entire_site_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * List of pagination types
 * @return array Pagination types
 */
function create_magazine_pagination_type() {
	$create_magazine_pagination_type = array(
		'numeric'     		=> esc_html__( 'Numeric','create-magazine' ),
		'older-newer' 		=> esc_html__( 'Older/Newer','create-magazine' ),
		'infinite-click' 	=> esc_html__( 'Infinite Click','create-magazine' ),
		'infinite-scroll' 	=> esc_html__( 'Infinite Scroll','create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_pagination_type', $create_magazine_pagination_type );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * Sidebar position
 * @return array Sidbar positions
 */
function create_magazine_sidebar_position() {
	$create_magazine_sidebar_position = array(
		'no-sidebar'	=> esc_html__( 'No-Sidebar', 'create-magazine' ),	
		'right-sidebar' => esc_html__( 'Right','create-magazine' ),
		'left-sidebar'  => esc_html__( 'Left','create-magazine' ),		
	);

	$output = apply_filters( 'create_magazine_sidebar_position', $create_magazine_sidebar_position );

	return $output;
}


/**
 * Site Layout
 * @return array Sidbar positions
 */
function create_magazine_site_layout() {
	$create_magazine_site_layout = array(
		'wide'  => esc_html__( 'Wide','create-magazine' ),
		'boxed' => esc_html__( 'Boxed','create-magazine' )
	);

	$output = apply_filters( 'create_magazine_site_layout', $create_magazine_site_layout );

	return $output;
}


/**
 * Loader types
 * @return array loader types
 */
function create_magazine_loader_type() {
	$create_magazine_loader_type = array(
		'icon'  => esc_html__( 'Icon','create-magazine' ),
		'image' => esc_html__( 'Image','create-magazine' )
	);

	$output = apply_filters( 'create_magazine_loader_type', $create_magazine_loader_type );

	return $output;
}

 
/**
 * Icon types
 * @return array Icon types
 */
function create_magazine_icon_type() {
	$create_magazine_icon_type = array(
		'fa-circle-o-notch'  => esc_html__( 'Circle-notch','create-magazine' ),
		'fa-cog ' 		 	 => esc_html__( 'Cog','create-magazine' ),
		'fa-refresh'		 => esc_html__( 'Refresh','create-magazine' ),
		'fa-spinner'		 => esc_html__( 'Spinner','create-magazine' ),
		'fa-recycle '		 => esc_html__( 'Recycle','create-magazine' ),
		'fa-adjust'			 => esc_html__( 'Adjust','create-magazine' ),
		'fa-arrows'			 => esc_html__( 'Arrows','create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_icon_type', $create_magazine_icon_type );

	return $output;
}

/**
 * Background color
 * @return array background color
 */
function create_magazine_background_color(){

	$create_magazine_background_color = array( 'bg-green', 'bg-orange', 'bg-light-red','bg-blue','bg-black', 'bg-grey','bg-red', 'bg-yellow', 'bg-cyan', 'bg-light-green', 'bg-dark-green',  'bg-dark-grey', 'bg-light-grey', 'bg-dark-blue','bg-darkest-blue',  'bg-dark-red' );

 	$output = apply_filters( 'create_magazine_background_color', $create_magazine_background_color );

 	return $output;
}

/**
 * Featured Story Source
 * @return array Source options
 */
function create_magazine_featured_story_options() {
	$create_magazine_featured_story_options = array(
		'demo'      		=> esc_html__( 'Demo', 'create-magazine' ),
		'post' 				=> esc_html__( 'Post', 'create-magazine' ),
		'category'      	=> esc_html__( 'Category', 'create-magazine' ),
		'tag'      			=> esc_html__( 'Tag', 'create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_featured_story_options', $create_magazine_featured_story_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}


/**
 * Photo Gallery Source
 * @return array Source options
 */
function create_magazine_photo_gallery_options() {
	$create_magazine_photo_gallery_options = array(
		'custom' 		=> esc_html__( 'Custom', 'create-magazine' ),
		'demo'      	=> esc_html__( 'Demo', 'create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_photo_gallery_options', $create_magazine_photo_gallery_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}


/**
 * Trending Now Source
 * @return array Source options
 */
function create_magazine_trending_now_options() {
	$create_magazine_trending_now_options = array(
		'demo'      		=> esc_html__( 'Demo', 'create-magazine' ),
		'category'      	=> esc_html__( 'Category', 'create-magazine' ),
		'tag'      			=> esc_html__( 'Tag', 'create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_trending_now_options', $create_magazine_trending_now_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}


/**
 * Contact Details Source
 * @return array Source options
 */
function create_magazine_contact_details_options() {
	$create_magazine_contact_details_options = array(
		'enabled' 		=> esc_html__( 'Enabled', 'create-magazine' ),
		'disabled'      => esc_html__( 'Disabled', 'create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_contact_details_options', $create_magazine_contact_details_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}


/**
 * Category Block two Source
 * @return array Source options
 */
function create_magazine_category_block_two_options() {
	$create_magazine_category_block_two_options = array(
		'demo'      		=> esc_html__( 'Demo', 'create-magazine' ),
		'category'      	=> esc_html__( 'Category', 'create-magazine' ),
		'tag'      			=> esc_html__( 'Tag', 'create-magazine' ),
		'post'				=> esc_html__( 'Post','create-magazine'),
	);

	$output = apply_filters( 'create_magazine_category_block_two_options', $create_magazine_category_block_two_options );

	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * Pagination
 * @return array site pagination options
 */
function create_magazine_theme_color() {
    $create_magazine_theme_color = array(
        'default'   => esc_html__( 'Default', 'create-magazine' ),
        'blue'      => esc_html__( 'Blue', 'create-magazine' ),
        'green'     => esc_html__( 'Green', 'create-magazine' ),
        'red'       => esc_html__( 'Red', 'create-magazine' ),
        'dark-green'=> esc_html__( 'Dark Green', 'create-magazine' ),
    );
    $output = apply_filters( 'create_magazine_theme_color', $create_magazine_theme_color );

    if ( ! empty( $output ) ) {
		ksort( $output );
	}
	
    return $output;
}